## What's Changed

### fixes

- feat(chat): feat: trace and log file config ([#4747](https://github.com/AstrBotDevs/AstrBot/issues/4747))
- fix: WebUI shows success message when skills upload failed ([#4768](https://github.com/AstrBotDevs/AstrBot/issues/4768))
- fix: cannot use tools when using skills-like tool schema mode ([#4775](https://github.com/AstrBotDevs/AstrBot/issues/4775))
- fix(context): llm tools' origin in WebUI displayed `unknown` ([#4776](https://github.com/AstrBotDevs/AstrBot/issues/4776))
